@@ -3,6 +3,7 @@ from tqdm import tqdm
 from sqlalchemy import create_engine
 from sqlalchemy.orm import sessionmaker
 from pygmailsorter.base import get_email_database
+from pygmailsorter.google.database import get_token_database
 from pygmailsorter.google.message import Message, get_email_dict
 from pygmailsorter.ml import (
     encode_df_for_machine_learning,
@@ -18,12 +19,14 @@ class GoogleMailBase:
         google_mail_service,
         database_email=None,
         database_ml=None,
+        database_token=None,
         user_id="me",
         db_user_id=1,
     ):
         self._service = google_mail_service
         self._db_email = database_email
         self._db_ml = database_ml
+        self._db_token = database_token
         self._db_user_id = db_user_id
         self._userid = user_id
         self._label_dict = self._get_label_translate_dict()
@@ -54,6 +57,9 @@ class GoogleMailBase:
                 label_lst=list(model_reload_dict.keys()),
                 return_labels=False,
             )
+            df_partial_features = df_partial_features.reindex(
+                sorted(df_partial_features.columns), axis=1
+            )
             model_recommendation_dict = get_predictions_from_machine_learning_models(
                 df_features=df_partial_features,
                 model_dict=model_reload_dict,
@@ -87,6 +93,12 @@ class GoogleMailBase:
         df_all_features, df_all_labels = encode_df_for_machine_learning(
             df=df_all, feature_lst=[], label_lst=[], return_labels=True
         )
+        df_all_features = df_all_features.loc[
+            :, ~df_all_features.columns.duplicated()
+        ].copy()
+        df_all_features = df_all_features.reindex(
+            sorted(df_all_features.columns), axis=1
+        )
         model_dict = fit_machine_learning_models(
             df_all_features=df_all_features,
             df_all_labels=df_all_labels,
@@ -391,4 +403,5 @@ class GoogleMailBase:
         session = sessionmaker(bind=engine)()
         db_email = get_email_database(engine=engine, session=session)
         db_ml = get_machine_learning_database(engine=engine, session=session)
-        return db_email, db_ml
+        db_token = get_token_database(engine=engine, session=session)
+        return db_email, db_ml, db_token
